const Blog = require('../models/blogschema')
const ApiError = require('../utils/ApiError');
const httpStatus = require('../utils/httpStatus');


const createblog = async (req, res) => {
  const blog = new Blog(req.body);
  const savedBlog = await blog.save();
  res.status(httpStatus.CREATED).json(savedBlog);
};


/* const getblogs = async (req, res) =>{
    const blogs = await Blog.find();
    res.send(blogs);
}; */



const getblogs = async (req, res) => {
  const { page = 1, limit = 10, sortBy = 'date', order = 'desc' } = req.query;

  // Validate pagination parameters
  if (isNaN(page) || isNaN(limit) || page < 1 || limit < 1) {
    throw new ApiError(httpStatus.BAD_REQUEST, 'Invalid pagination parameters');
  }

  // Validate sorting parameters
  const allowedSortFields = ['date', 'title']; // Add or remove fields as needed
  if (!allowedSortFields.includes(sortBy)) {
    throw new ApiError(httpStatus.BAD_REQUEST, 'Invalid sort field');
  }

  if (!['asc', 'desc'].includes(order.toLowerCase())) {
    throw new ApiError(httpStatus.BAD_REQUEST, 'Invalid sort order');
  }

  const options = {
    page: parseInt(page, 10),
    limit: parseInt(limit, 10),
    sort: { [sortBy]: order === 'desc' ? -1 : 1 },
    lean: true,
  };

  const result = await Blog.paginate({}, options);

  if (result.docs.length === 0 && page > 1) {
    throw new ApiError(httpStatus.NOT_FOUND, 'No posts found for this page');
  }

  res.json({
    blogs: result.docs,
    totalPages: result.totalPages,
    currentPage: result.page,
    totalPosts: result.totalDocs,
  });
}; 


const getblog = async(req, res) =>{
  const blogs = await Blog.find();
  const blog = await blogs.find(c => c.id === req.params.id);
  if(!blog) res.status(404).send('The blog with the given ID was not found.')
  res.send(blog);
};

const updateblog = async (req, res) => {
  const post = await Blog.findByIdAndUpdate(req.params.id, req.body, { new: true });
  if (!post) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Post not found');
  }
  res.json(post);
};

const deleteblog = async (req, res) => {
  const post = await Blog.findByIdAndDelete(req.params.id);
  if (!post) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Post not found');
  }
  res.json({ message: 'Post deleted successfully' });
};

module.exports = {
  createblog,
  getblogs,
  getblog,
  updateblog,
  deleteblog
};